![License](https://img.shields.io/github/license/apecosm/apecosm-python)
[![PyPI](https://img.shields.io/pypi/v/apecosm)](https://pypi.org/project/apecosm/)
[![Latest Release](https://img.shields.io/github/release/apecosm/apecosm-python)](https://github.com/apecosm/apecosm-python/issues)
[![GitHub Issues](https://img.shields.io/github/issues/apecosm/apecosm-python)](https://github.com/apecosm/apecosm-python/issues)

<div align="center">
    <img src="https://avatars3.githubusercontent.com/u/71690308?s=400&u=fec22b3993d64d6f6def5228bdf0da8a8e2b0286&v=4" width=100>
</div>

# Ichthyop

Apecosm is a model that aims to represent the spatialized dynamics of open ocean pelagic ecosystems in the global ocean. 

This python package is dedicated to the analysis of Apecosm's outputs. 
- Plots maps
- Compute averages (spatial, temporal)
- Computes size spectra
